ete2.treeview.faces.Face

Package ete2 :: Package treeview :: Module faces :: Class Face |
[hide private]
[frames] | no frames]

# Class Face

source code

    object --+
             |
            Face

Known Subclasses:
  - TextFace
  - , ImgFace
  - , ProfileFace
  - , SequenceFace
  - , ValidationFace

Standard definition of a face node object.

This class is not functional and it should only be used to create other faces objects. By inheriting this class, you set all the essential attributes, however the update_pixmap() function is required to be reimplemented for convenience.

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_size(self) | source code
_width(self) | source code
_height(self) | source code
load_pixmap_from_file(self, filename) | source code
update_pixmap(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)